@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -36,7 +36,8 @@ class AppKitApacheLoggerFormat extends AgaviLoggerLayout {
                                          AgaviLogger::ERROR => 'error',
                                          AgaviLogger::FATAL => 'fatal',
                                          AgaviLogger::INFO  => 'info',
-                                         AgaviLogger::WARN  => 'warn'
+                                         AgaviLogger::WARN  => 'warn',
+                                         AppKitLogger::COMMAND => 'command'
                                      );
 
     public static function levenToString($level) {
